patch applied (packages/containers): Settle performance issues in
IntMap and IntSet.
Ian Lynagh
igloo at earth.li
Fri Nov 12 17:09:24 EST 2010
Fri Oct 29 16:16:53 PDT 2010 Milan Straka <fox at ucw.cz>
* Settle performance issues in IntMap and IntSet.
The worker-wrapper transformation is removed from
all functions but lookup and member. This is the
only place where it causes benefits -- a 10% to
15% speedup. It increases memory allocation
slightly (0-5%), but the effect on GHC is really
minor.
Also INLINE/INLINABLE hints are not really needed,
GHC figures it all by itself. The explicit INLINE
were left on internal functions that are crutial
to INLINE because of performance.
M ./Data/IntMap.hs -167 +140
M ./Data/IntSet.hs -54 +52
View patch online:
http://darcs.haskell.org/cgi-bin/darcsweb.cgi?r=packages/containers;a=darcs_commitdiff;h=20101029231653-7b66e-6c920f85ededf1eace5e9d0a2cf0d2ccf2cf2209.gz
More information about the Cvs-libraries
mailing list